@@ -22,6 +22,8 @@ DEFAULT_LOGS_WITH_COLORS = False
 
 APPLICATION = 'application'
 
+DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION = f'{c.DOT_SPACE}Check {log.LOG} level logs for more information'
+
 IGNORE_MODULES = list()
 IGNORE_REOURCES = list()
 
@@ -689,20 +691,30 @@ def importModule(resourceModuleName, muteLogs=False, reload=False, ignoreList=IG
         try :
             if reload :
                 IMPORT_CASHE[resourceModuleName] = importlib.reload(resourceModuleName)
-            elif resourceModuleName not in IMPORT_CASHE:
+            elif (
+                resourceModuleName not in IMPORT_CASHE or
+                required and ObjectHelper.isNone(IMPORT_CASHE.get(resourceModuleName))
+            ):
                 IMPORT_CASHE[resourceModuleName] = importlib.import_module(resourceModuleName)
         except Exception as exception:
+            importException = exception
             if not muteLogs :
                 log.log(importModule, f'Not possible to import "{resourceModuleName}" module. Going for a second attempt', exception=exception)
             try :
                 IMPORT_CASHE[resourceModuleName] = __import__(resourceModuleName)
-            except Exception as innerException :
+            except Exception as innerException:
                 importException = innerException
                 IMPORT_CASHE[resourceModuleName] = None
                 if not muteLogs :
                     log.log(importModule, f'Not possible to import "{resourceModuleName}" module in the second attempt either. Original cause: {str(exception)}. Returning "{IMPORT_CASHE.get(resourceModuleName)}" by default', exception=innerException)
         if required and ObjectHelper.isNone(IMPORT_CASHE.get(resourceModuleName)):
-            raise Exception(f'Not possible to import module "{resourceModuleName}"{c.DOT_SPACE_CAUSE}{getExceptionTextWithoutDotAtTheEnd(importException)}. Check {log.LOG} level logs for more information')
+            if not importException:
+                try:
+                    IMPORT_CASHE[resourceModuleName] = __import__(resourceModuleName)
+                    return IMPORT_CASHE.get(resourceModuleName)
+                except Exception as exception:
+                    importException = exception
+            raise Exception(f'Not possible to import module "{resourceModuleName}"{c.DOT_SPACE_CAUSE}{getExceptionTextWithoutDotAtTheEnd(importException)}{DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION}')
         return IMPORT_CASHE.get(resourceModuleName)
 
 
@@ -715,7 +727,7 @@ def importResource(resourceName, resourceModuleName=None, muteLogs=False, reload
             resourceModuleName = innerResourceName
         if (
             reload or
-            resourceModuleName not in IMPORT_CASHE.keys() or
+            resourceModuleName not in IMPORT_CASHE or
             required and ObjectHelper.isNone(IMPORT_CASHE.get(resourceModuleName))
         ):
             IMPORT_CASHE[resourceModuleName] = importModule(resourceModuleName, muteLogs=muteLogs, reload=reload, required=required)
@@ -742,7 +754,8 @@ def importResource(resourceName, resourceModuleName=None, muteLogs=False, reload
             if not muteLogs :
                 log.log(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module', exception=exception)
         if required and ObjectHelper.isNone(accumulatedResourceModule):
-            raise Exception(f'Error while importing {innerResourceName} resource from {resourceModuleName} module{c.DOT_SPACE_CAUSE}{getExceptionTextWithoutDotAtTheEnd(importException)}. Check {log.LOG} level logs for more information')
+            cause = getExceptionTextWithoutDotAtTheEnd(importException)
+            raise Exception(f'Error while importing {innerResourceName} resource from {resourceModuleName} module{c.DOT_SPACE_CAUSE}{cause}{c.BLANK if cause.endswith(DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION) else DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION}')
         return IMPORT_CASHE.get(getCompositeModuleName(resourceModuleName, nameList))
 
 
@@ -751,6 +764,8 @@ def getCompositeModuleName(resourceModuleName, resourceNameList):
 
 
 def getExceptionTextWithoutDotAtTheEnd(exception):
+    if ObjectHelper.isNone(exception):
+        return "Unknown"
     exceptionText = str(exception)
     while ObjectHelper.isNeitherNoneNorBlank(exceptionText) and c.DOT == exceptionText[-1]:
         exceptionText = exceptionText[:-1]
